import { useEffect, useState } from "react"
import { ScrollView, Text, VStack } from "native-base"
import { useSelector } from "react-redux"
import { RootState } from "../../stores/store"
import ItemPreview from "./ItemPreview"
import { ItemPreviewType } from "../../types/listViewTypes"
import { log } from "../../logging/logger"
import ListViewInventoryGroup from "./ListViewInventoryGroup"

type ListViewProps = {
    navigation: any
}

const ListView = (props: ListViewProps) => {

    const inventories = useSelector((state: RootState) => state.listView.inventories)


    return (
        <>
            <Text fontSize={ 16 } fontWeight={ "bold" } color={"primary.500"}>Search results:</Text>
            { inventories && inventories.length > 0 ?
                (inventories.length > 1 ?
                    inventories.map((inventory) => (
                            <ListViewInventoryGroup
                                inventoryName={ inventory.name }
                                inventoryLabel={ inventory.label }
                                navigation={ props.navigation }
                            />
                        )
                    ) : (
                        <ListViewInventoryGroup
                            inventoryName={ inventories[0].name }
                            inventoryLabel={ inventories[0].label }
                            navigation={ props.navigation }
                            defaultOpen={ true }
                        />
                    )) : (
                    <Text alignSelf={ "center" }>No results found</Text>
                )
            }
        </>
    )
}

export default ListView